@@ -46,7 +46,7 @@ function (form, data, rscale = 1, steps = 8, delmax = 0.999999)
     comp <- solve(diag(sx$d, ncol = p)) %*% t(sx$u) %*% cry
     bstar <- sx$v %*% comp
     exev <- matrix(0, p, 1)
-    infd <- matrix(0, p, 1)
+    infd <- as.numeric(matrix(NA, p, 1))
     delta <- matrix(1, p, 1)
     idty <- diag(p)
     d <- idty
@@ -69,8 +69,10 @@ function (form, data, rscale = 1, steps = 8, delmax = 0.999999)
         r2 = r2, s2 = s2, prinstat = stat, gmat = sx$v)
     OmR2dN <- (1 - r2 )/n
     dMSE <- rep(1,p)      # meaningless initial values...
+    mMSE <- p             # Maximum possible value...
     for( i in 1:p ) {
         dMSE[i] <- (rho[i])^2 / ( (rho[i])^2 + OmR2dN )    # Maximum-Likelihood estimate...
+        mMSE <- mMSE - dMSE[i]
     }
     mcal <- 0
     kinc <- 1/min(dMSE)      # innitially > 1 but decreasing...
@@ -83,9 +85,10 @@ function (form, data, rscale = 1, steps = 8, delmax = 0.999999)
     E <- Inf
     R <- Inf
     maxinc <- p * steps      # Number of Lattice Steps with "m" strictly > ZERO.
+    IDhit <- 0
     for (inc in 1:maxinc) {
         mobj <- inc/steps
-        iter <- m.ukd(mobj, p, dMSE)  # Function defined below...
+        iter <- kofm(mobj, p, dMSE)  # Function defined below...
         kinc <- iter$kStar
         d <- iter$d          # Diagonal Matrix, p x p...
         dinc <- diag(d)      # Diagonal Elements only...
@@ -124,18 +127,18 @@ function (form, data, rscale = 1, steps = 8, delmax = 0.999999)
             sfac <- 1e-05
         eign <- eigen(emse/sfac)
         einc <- sort(eign$values) * sfac         # Increasing order; negative values first...
-        cinc <- matrix(0, p, 1)
+        cinc <- as.numeric(matrix(NA, p, 1)) 
         if (is.na(einc[1])) 
             einc[1] <- 0
-        if (einc[1] + 1 -delmax < 0) {              # New Correction... 
+        if (einc[1] + 1 - delmax < 0) {          # New Correction... 
             eign$vectors <- sx$v %*% eign$vectors
             cinc <- eign$vectors[, p]
             if (rscale == 2) {
                 cinc <- cinc %*% xscale
                 cinc <- cinc/sqrt(sum(cinc^2))
             }
-            if (t(cold) %*% cinc < 0) 
-                cinc <- -1 * cinc
+            if (IDhit > 0 && t(cold) %*% cinc < 0) cinc <- -1 * cinc 
+            IDhit <- 1
             cold <- cinc
         }
         bstar <- cbind(bstar, binc)
@@ -170,7 +173,7 @@ function (form, data, rscale = 1, steps = 8, delmax = 0.999999)
     }
     RXolist <- c(RXolist, list(coef = bstar, rmse = risk, 
         exev = exev, infd = infd, spat = delta, mlik = mlik, 
-        sext = sext, mUnr = mUnr, mClk = mClk, minC = minC,
+        sext = sext, mUnr = mUnr, mMSE = mMSE, mClk = mClk, minC = minC,
         dMSE = dMSE))
     class(RXolist) <- "unr.ridge"
     RXolist
@@ -235,7 +238,7 @@ function (x, trace = "all", trkey = FALSE, ...)
         scan()  
     }  
     if (trace == "all" || trace == "seq" || trace == "infd") {
-        plot(mcalp, x$infd, ann = FALSE, type = "n")  
+        plot(mcalp, x$infd, ann = FALSE, type = "n", ylim = c(-1,1))  
         abline(v = mV, col = "gray", lty = 2, lwd = 2)  		
         abline(h = 0, col = gray(0.9), lwd = 2)  
         for (i in 1:x$p) lines(mcal, x$infd[, i], col = i, lty = i, 
@@ -281,15 +284,19 @@ function (x, ...)
     cat("minimize the minus-two-log-likelihood statistics listed below:\n")
     print.default(x$mlik, quote = FALSE)
     cat("\nExtent of Shrinkage Statistics...\n")
-    print.default(x$sext, quote = FALSE)  
-    cat("\n    Most Likely UNRestricted Shrinkage Extent, mUnr =", x$mUnr)
-    cat("\n    Corresponding -2*log(LikelihoodRatio) statistic = 0.0")  	
-    cat("\n    Most Likely m-Value on the Lattice,        mClk =", x$mClk)
-    cat("\n    Smallest Observed -2*log(LikelihoodRatio), minC =", x$minC)    	
+    print.default(x$sext, quote = FALSE)
+    if (x$r2 > 0.999) {
+        cat("\n\nWARNING! R-squared exceeds 0.999;")
+        cat("  Details of calculations are possibly Misleading...\n")
+    }	
+    cat("\n    Most Likely UNRestricted Shrinkage Extent,  mUnr =", x$mUnr)
+    cat("\n    Corresponding Expected -2*log(Likelihood Ratio)  = 0.0")  	
+    cat("\n    Most Likely m-Value on Observed Lattice,    mClk =", x$mClk)
+    cat("\n    Smallest Observed -2*log(Likelihood Ratio), minC =", x$minC)    	
     cat("\n    dMSE Estimates =", x$dMSE, "\n\n")	
-} 
+}
 
-"m.ukd" <-
+"kofm" <-
 function (muobj, p, dMSE, delmax = 0.999999) 
 {
     kM <- matrix(1,1,p)/dMSE[order(dMSE)]   # Vector of decreasing (1/dMSE) values...
